Glossary
########

Acronyms
********

.. glossary::

   ESF
     Equilibrium Slag Function
   
   GGS
     Groeien met Groen Staal

   BOF
     Basic Oxygen Furnace

   MQM
     Modifed Quasichemical Model
    
   REF
     Reducing Electric Furnace

Definitions
***********

.. glossary::
   
   auxi-mpp
          The python package containing material physical property models, where 'auxi' means help, and 'mpp' means material physical properties. 
